@@ -12,8 +12,8 @@ class Ncaab(ncaablike.NCAABlike):
     def __init__(self) -> None:
 
         meta = sportsdataio_meta.SportsDataIOMetalike=sportsdataio_meta.SportsDataIOmeta(
-            str(dotenv_values()["SPORTS_DATA_KEY"]),
-            str(dotenv_values()["SPORTS_DATA_DOMAIN"])
+            "SPORTS_DATA_KEY",
+            "SPORTS_DATA_DOMAIN"
         )
         self.games = game.games.Games(meta)
 
